@@ -15,7 +15,13 @@ from .version import __version__
 from .DataAPI import retry_interval, max_retries
 
 
-
-
-
-
+try:
+    DataAPI.api_base.replace_api_files()
+    for e in list(sys.modules.keys()):
+        if e.startswith('DataAPI') or e.startswith('uqer.DataAPI'):
+            del sys.modules[e]
+    from . import DataAPI
+except:
+    import traceback
+    print(traceback.format_exc())
+    print('upgrade fail.')
\ No newline at end of file
